#!/bin/sh
#
# SuxPanel user installer script
# Version 0.1
# Copyright (c) Leandro Pereira <leandro@linuxmag.com.br>
#

DIR="${HOME}/.suxpanel"

if [ -e $DIR ]; then
	echo "$DIR exists, aborting."
	exit 1
fi

if [ ! -e /usr/share/suxpanel ]; then
	echo "make install first :)"
	exit 1
fi

echo -e "--- Installing SuxPanel..."

APPS="$DIR/apps"
APPBAR="$DIR/appbar"
MODULE="$DIR/modules.ini"

mkdir -p $APPS
mkdir -p $APPBAR
touch $MODULE

echo -e "--- Searching modules..."
P=`pwd`
cd /usr/share/suxpanel/plugins
for i in $( find *.so ); do
	case $i in
		clock.so)
			ALIGN="r" ;;
		apps.so)
			ALIGN="l" ;;
		appbar.so)
			ALIGN="l" ;;
		mixer.so)
			ALIGN="r" ;;
		*)
			ALIGN="l" ;;
	esac

	echo -n " $i"

	echo "$ALIGN=`pwd`/$i" >> $MODULE
done
cd $P

echo ""

FILEMAN="rox nautilus konqueror gmc"

for i in $FILEMAN ; do
	echo -e "--- Searching for $i file manager..."
	for j in `which $i`; do
		if [ -e "$j" ]; then
			echo "Found in $j."
			FILEMGR="$j"
			break;
		fi
	done

	if [ -e "$FILEMGR" ]; then break; fi
done

echo -e "--- Creating menu entries..."

mkdir "$APPS/Home Directory"
echo -e "#!/bin/sh\n$FILEMGR \"$HOME\"" > "$APPS/Home Directory/AppRun"
chmod +x "$APPS/Home Directory/AppRun"
ln -s /usr/share/pixmaps/gnome-home.png "$APPS/Home Directory/AppIcon.xpm"
ln -s "$APPS/Home Directory" "$APPBAR/"

mkdir "$APPS/Terminal"
echo -e "#!/bin/sh\nxterm" > "$APPS/Terminal/AppRun"
chmod +x "$APPS/Terminal/AppRun"
ln -s /usr/share/pixmaps/gnome-terminal.png "$APPS/Terminal/AppIcon.xpm"
ln -s "$APPS/Terminal" "$APPBAR/"

echo -e "--- Importing GNOME menu entries"
P=`pwd`
cd $APPS
for i in $( find /usr/share/applications/ | grep desktop ); do
	APPICON=`cat $i|grep "Icon"|cut -d= -f2`
	APPNAME=`cat $i|grep "Name="|cut -d= -f2`
	APPEXEC=`cat $i|grep "Exec"|cut -d= -f2`
	CATEGORY=`cat $i|grep "Categories="|cut -d= -f2`

	# Slow, not quite perfect, but works. Feel free to improve! :)
	CATEGORY=$(echo $CATEGORY | sed s/\;/\\//g | sed s/GNOME//g | sed s/Application//g)
	CATEGORY=$(echo $CATEGORY | sed s/X\-\.*//g | sed s/AudioVideo/Multimedia/g);
	CATEGORY=$(echo $CATEGORY | sed s/Core/Utility/g )
	
	APPNAME="$APPS$CATEGORY/$APPNAME"

	if [ ! -e "$APPNAME" ]; then
		echo -n "." 

		mkdir -p "$APPNAME" 2>/dev/null
		rm -f "$APPNAME/AppRun" 2>/dev/null
		echo -e "#!/bin/sh\n$APPEXEC" > "$APPNAME/AppRun" 2>/dev/null
		chmod +x "$APPNAME/AppRun" 2>/dev/null
		ln -s "/usr/share/pixmaps/$APPICON" "$APPNAME/AppIcon.xpm" 2>/dev/null
	fi
done
cd $P

echo ""

echo "Done installing."

echo ""

echo "Your menu is saved in $APPS."
echo " - Groups are created with ordinary directories."
echo " - Change the directory icon with a .DirIcon file."
echo " - Put some AppDir inside the directories."
echo "More information about ''AppDir'' may be found at:"
echo " - http://rox.sourceforge.net/appdirs.html"
echo ""

echo -n "Open $APPS with $FILEMGR? (Y/n) "
read foo

if [ "$foo" == "n" ]; then exit; fi

$FILEMGR "$APPS"
